@@ -50,7 +50,7 @@ def build_app(
         remove_last_build (bool, optional): If some problems, it is possible to delete build and dist folders. Defaults to False.
         console (bool, optional): Before app run terminal window appears (good for debugging). Defaults to False.
         debug (bool, optional): If no console, then dialog window with traceback appears. Defaults to False.
-        icon ((Path, str), optional): Path to .ico file (!no png!). Defaults to None.
+        icon ((Path, str), optional): Path or name with extension to .ico file (!no png!). Defaults to None.
         hidden_imports (list, optional): If app is not working, it can be because some library was not builded. Add such
             libraries into this list. Defaults to [].
         ignored_packages (list, optional): Libraries take space even if not necessary. Defaults to [].
@@ -74,7 +74,7 @@ def build_app(
     if not main_file_path.exists():
 
         # Iter paths and find the one
-        main_file_path = misc.find_path(main_file_path)
+        main_file_path = misc.find_path(main_file_path, exclude=['node_modules', 'build'])
 
         if not main_file_path.exists():
             raise KeyError("Main file not found, not infered and must be configured in params...")
@@ -86,6 +86,16 @@ def build_app(
 
     main_folder_path = main_file_path.parent
 
+    icon_path = Path(icon)
+
+    if not icon_path.exists():
+
+        # Iter paths and find the one
+        icon_path = misc.find_path(icon_path, exclude=['node_modules', 'build'])
+
+        if not icon_path.exists():
+            raise KeyError("Icon not found, not infered check path or name...")
+
     if preset == 'eel':
         if not web_path:
             web_path = misc.find_path('index.html', exclude=['public', 'node_modules', 'build']).parent
@@ -109,7 +119,7 @@ def build_app(
     if dist_path.exists():
         try:
             shutil.rmtree(dist_path, ignore_errors=False)
-        except PermissionError:
+        except (PermissionError, OSError):
             raise PermissionError(mylogging.return_str("App is opened (May be in another app(terminal, explorer...)). Close it first."))
 
     generated_warning = """
@@ -170,7 +180,7 @@ exe = EXE(pyz,
         strip=False,
         upx=True,
         console={console},
-        icon={f'{str(icon)}' if icon else None})
+        icon={f"'{icon_path.as_posix()}'" if icon else None})
 coll = COLLECT(exe,
             a.binaries,
             a.zipfiles,
