@@ -11,6 +11,7 @@ from pathlib import Path
 import warnings
 import pandas as pd
 import numpy as np
+from ast import literal_eval
 
 from . import misc
 
@@ -134,6 +135,7 @@ def help_starter_pack_vue_app():
     ### app.py
     ###########
 
+    ```python
     from mypythontools import pyvueel
 
     # Expose python functions to Js with decorator
@@ -147,6 +149,7 @@ def help_starter_pack_vue_app():
     # End of file
     if __name__ == '__main__':
         pyvueel.run_gui()
+    ```
 
     #########
     ### gui
@@ -170,31 +173,63 @@ def help_starter_pack_vue_app():
     ### main.js
     ############
 
-    if (ProcessingInstruction.env.NODE_ENV !== 'production') {
-      window.eel.set_host("ws://localhost:8686")
+    ```js
+    if (process.env.NODE_ENV == 'development') {
+    Vue.config.productionTip = true
+    Vue.config.devtools = true
+    window.eel.set_host("ws://localhost:8686");
+    } else {
+    Vue.config.productionTip = false
+    Vue.config.devtools = false
     }
 
     // You can expose function to be callable from python. Import and then
     // window.eel.expose(mutate, 'mutate')
+    ```
 
     ##########
     ### .env
     #########
 
     create empty files .env.development and add `VUE_APP_EEL=http://localhost:8686/eel.js`
-
     create empty .env.production and add `VUE_APP_EEL=eel.js`
 
+
     #################
     ### index.html
     ###############
 
     In public folder
 
-    ```
+    ```html
     <script type="text/javascript" src="<%= VUE_APP_EEL %>"></script>
     ```
 
+    ###################
+    ### vue.config.js
+    #################
+
+    ```js
+    let devtool_mode
+    if (process.env.NODE_ENV === 'development') {
+    devtool_mode = 'source-map';
+    } else {
+    devtool_mode = false;
+    }
+
+    module.exports = {
+    outputDir: "web_builded",
+    transpileDependencies: [
+        "vuetify"
+    ],
+    productionSourceMap: process.env.NODE_ENV != 'production',
+
+    configureWebpack: {
+        devtool: devtool_mode,
+    }
+    }
+    ```
+
     #################
     ### Tips, trips
     ################
@@ -223,12 +258,17 @@ def json_to_py(json):
     """
 
     evaluated = {}
-    for i, j in json.items():
-        try:
-            evaluated[i] = eval(j)
-        except Exception:
-            evaluated[i] = j
-    return evaluated
+    if json:
+        for i, j in json.items():
+            try:
+                settigs_val = literal_eval(j)
+                # If user type 1,3 and mean decimal point
+                if isinstance(settigs_val, tuple):
+                    settigs_val = literal_eval(j.replace(',', '.'))
+                evaluated[i] = settigs_val
+            except Exception:
+                evaluated[i] = j
+        return evaluated
 
 
 def to_vue_plotly(data, names=None):
